## $Id: viewlets.py 10691 2013-11-04 09:19:39Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import grok
from waeup.kofa.students.viewlets import (
    AddPreviousPaymentActionButton, AddBalancePaymentActionButton,
    ManageActionButton)
from waeup.kofa.students.interfaces import IStudent
from waeup.kofa.students.browser import StudentBaseDisplayFormPage
from waeup.kofa.students.workflow import (
    ADMITTED, PAID, REQUESTED, RETURNING, CLEARED, REGISTERED,
    VALIDATED, GRADUATED, TRANSCRIPT, CREATED, CLEARANCE)
from waeup.kwarapoly.interfaces import MessageFactory as _

class AddPreviousPaymentActionButton(AddPreviousPaymentActionButton):

    @property
    def target_url(self):
        return ''

class AddBalancePaymentActionButton(AddBalancePaymentActionButton):

    @property
    def target_url(self):
        return ''

class AdmissionNotificationActionButton(ManageActionButton):
    grok.order(4)
    grok.context(IStudent)
    grok.view(StudentBaseDisplayFormPage)
    grok.require('waeup.viewStudent')
    icon = 'actionicon_pdf.png'
    text = _('Download admission notification')
    target = 'admission_notification.pdf'

    @property
    def target_url(self):
        if self.context.state not in (ADMITTED, CLEARANCE, REQUESTED, CLEARED):
            return ''
        return self.view.url(self.view.context, self.target)

class AdmissionSlipActionButton(ManageActionButton):
    grok.order(4)
    grok.context(IStudent)
    grok.view(StudentBaseDisplayFormPage)
    grok.require('waeup.viewStudent')
    icon = 'actionicon_pdf.png'
    text = _('Download admission letter')
    target = 'admission_slip.pdf'

    @property
    def target_url(self):
        if self.context.state in (CREATED, ADMITTED,
                                  CLEARANCE, REQUESTED, CLEARED):
            return ''
        return self.view.url(self.view.context, self.target)